##  Survey API
As an administrator, you can manage surveys programmatically using the [Poll REST API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fopenapi-explorer%3Furls.primaryName%3DPoll "https://eu.leanix.net/openapi-explorer?urls.primaryName=Poll"). To learn more, see [Retrieving Survey Results](https://help.sap.com/docs/leanix/ea/retrieving-survey-results?locale=en-US&state=PRODUCTION&version=CLOUD "Retrieve survey results using the Survey REST API.").
If you're an SAP LeanIX user and interested in learning how to create your survey through a step-by-step video tutorial, you can access the SAP LeanIX Academy course on [Surveys![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Facademy.leanix.net%2Fgetting-data-into-leanix%2F1797767 "https://academy.leanix.net/getting-data-into-leanix/1797767").
